@@ -368,6 +368,9 @@ class GemfileLockParser:
         # the final tree of dependencies, keyed by name
         self.dependency_tree = {}
 
+        # the package that the gemfile.lock is for
+        self.primary_gem = None
+
         # a flat dict of all gems, keyed by name
         self.all_gems = {}
 
@@ -399,6 +402,9 @@ class GemfileLockParser:
         # finally refine the collected data
         self.refine()
 
+        # set primary gem
+        self.set_primary_gem()
+
     def reset_state (self):
         self.state = None
         self.current_options = {}
@@ -409,6 +415,13 @@ class GemfileLockParser:
         for gem in self.all_gems.values():
             gem.refine()
 
+    def set_primary_gem(self):
+        for gem in self.all_gems.values():
+            if not gem.type == PATH:
+                continue
+            self.primary_gem = gem
+            break
+
     def get_or_create(self, name, version=None, platform=None):
         """
         Return an existing gem if it exists or creates a new one.
