@@ -7,20 +7,13 @@
 # See https://aboutcode.org for more information about nexB OSS projects.
 #
 
-from functools import partial
 import io
 import json
-import logging
-import sys
+from functools import partial
 
-import attr
-
-from commoncode import filetype
-from commoncode import fileutils
 from packagedcode import models
 from packagedcode.utils import combine_expressions
 
-
 """
 Parse PHP composer package manifests, see https://getcomposer.org/ and
 https://packagist.org/
@@ -29,148 +22,102 @@ TODO: add support for composer.lock and packagist formats: both are fairly
 similar.
 """
 
-TRACE = False
 
-
-def logger_debug(*args):
-    pass
-
-
-logger = logging.getLogger(__name__)
-
-if TRACE:
-    logging.basicConfig(stream=sys.stdout)
-    logger.setLevel(logging.DEBUG)
-
-    def logger_debug(*args):
-        return logger.debug(' '.join(isinstance(a, str) and a or repr(a) for a in args))
-
-
-@attr.s()
-class PHPComposerPackage(models.Package):
-    metafiles = (
-        'composer.json',
-        'composer.lock',
-    )
-    extensions = ('.json', '.lock',)
-    mimetypes = ('application/json',)
-
-    default_type = 'composer'
-    default_primary_language = 'PHP'
-    default_web_baseurl = 'https://packagist.org'
-    default_download_baseurl = None
-    default_api_baseurl = 'https://packagist.org/p'
+class BasePhpComposerHandler(models.DatafileHandler):
 
     @classmethod
-    def recognize(cls, location):
-        for package in parse(location):
-            yield package
+    def assemble(cls, package_data, resource, codebase, package_adder):
+        datafile_name_patterns = (
+            'composer.json',
+            'composer.lock',
+        )
+
+        if resource.has_parent():
+            dir_resource=resource.parent(codebase)
+        else:
+            dir_resource=resource
+
+        yield from cls.assemble_from_many_datafiles(
+            datafile_name_patterns=datafile_name_patterns,
+            directory=dir_resource,
+            codebase=codebase,
+            package_adder=package_adder,
+        )
 
     @classmethod
-    def get_package_root(cls, manifest_resource, codebase):
-        return manifest_resource.parent(codebase)
+    def assign_package_to_resources(cls, package, resource, codebase, package_adder):
+        return models.DatafileHandler.assign_package_to_parent_tree(package, resource, codebase, package_adder)
 
-    def repository_homepage_url(self, baseurl=default_web_baseurl):
-        if self.namespace:
-            return '{}/packages/{}/{}'.format(baseurl, self.namespace, self.name)
-        else:
-            return '{}/packages/{}'.format(baseurl, self.name)
-
-    def api_data_url(self, baseurl=default_api_baseurl):
-        if self.namespace:
-            return '{}/packages/{}/{}.json'.format(baseurl, self.namespace, self.name)
-        else:
-            return '{}/packages/{}.json'.format(baseurl, self.name)
-
-    def compute_normalized_license(self):
+    @classmethod
+    def compute_normalized_license(cls, package):
         """
         Per https://getcomposer.org/doc/04-schema.md#license this is an expression
         """
-        return compute_normalized_license(self.declared_license)
+        return compute_normalized_license(package.declared_license)
 
 
-def compute_normalized_license(declared_license):
-    """
-    Return a normalized license expression string detected from a list of
-    declared license items or string type.
-    """
-    if not declared_license:
-        return
+class PhpComposerJsonHandler(BasePhpComposerHandler):
+    datasource_id = 'php_composer_json'
+    path_patterns = ('*composer.json',)
+    default_package_type = 'composer'
+    default_primary_language = 'PHP'
+    description = 'PHP composer manifest'
+    documentation_url = 'https://getcomposer.org/doc/04-schema.md'
 
-    detected_licenses = []
+    @classmethod
+    def parse(cls, location):
+        """
+        Yield one or more Package manifest objects given a file ``location``
+        pointing to a package archive, manifest or similar.
 
-    if isinstance(declared_license, str):
-        if declared_license == 'proprietary':
-            return declared_license
-        if '(' in declared_license and ')' in declared_license and ' or ' in declared_license:
-            declared_license = declared_license.strip().rstrip(')').lstrip('(')
-            declared_license = declared_license.split(' or ')
-        else:
-            return models.compute_normalized_license(declared_license)
-
-    if isinstance(declared_license, list):
-        for declared in declared_license:
-            detected_license = models.compute_normalized_license(declared)
-            detected_licenses.append(detected_license)
-    else:
-        declared_license = repr(declared_license)
-        detected_license = models.compute_normalized_license(declared_license)
-
-    if detected_licenses:
-        # build a proper license expression: the defaultfor composer is OR
-        return combine_expressions(detected_licenses, 'OR')
-
-
-def is_phpcomposer_json(location):
-    return filetype.is_file(location) and fileutils.file_name(location).lower() == 'composer.json'
-
-
-def is_phpcomposer_lock(location):
-    return filetype.is_file(location) and fileutils.file_name(location).lower() == 'composer.lock'
-
-
-def parse(location):
-    """
-    Yield Package objects from a composer.json or composer.lock file. Note that
-    this is NOT exactly the packagist .json format (all are closely related of
-    course but have important (even if minor) differences.
-    """
-    if is_phpcomposer_json(location):
+        Note that this is NOT exactly the packagist.json format (all are closely
+        related of course but have important (even if minor) differences.
+        """
         with io.open(location, encoding='utf-8') as loc:
-            package_data = json.load(loc)
-        yield build_package_from_json(package_data)
+            package_json = json.load(loc)
 
-    elif is_phpcomposer_lock(location):
-        with io.open(location, encoding='utf-8') as loc:
-            package_data = json.load(loc)
-        for package in build_packages_from_lock(package_data):
-            yield package
+        yield build_package_data(package_json)
 
 
-def build_package_from_json(package_data):
-    """
-    Return a composer Package object from a package data mapping or None.
-    """
-    # A composer.json without name and description is not a usable PHP
-    # composer package. Name and description fields are required but
-    # only for published packages:
-    # https://getcomposer.org/doc/04-schema.md#name
-    # We want to catch both published and non-published packages here.
-    # Therefore, we use "private-package-without-a-name" as a package name if
-    # there is no name.
+def get_repository_homepage_url(namespace, name):
+    if namespace and name:
+        return f'https://packagist.org/packages/{namespace}/{name}'
+    elif name:
+        return f'https://packagist.org/packages/{name}'
+
+
+def get_api_data_url(namespace, name):
+    if namespace and name:
+        return f'https://packagist.org/p/packages/{namespace}/{name}.json'
+    elif name:
+        return f'https://packagist.org/p/packages/{name}.json'
+
+
+def build_package_data(package_data):
+
+    # Note: A composer.json without name and description is not a usable PHP
+    # composer package. Name and description fields are required but only for
+    # published packages: https://getcomposer.org/doc/04-schema.md#name We want
+    # to catch both published and non-published packages here. Therefore, we use
+    # None as a package name if there is no name.
 
     ns_name = package_data.get('name')
     is_private = False
     if not ns_name:
         ns = None
-        name = 'private-package-without-a-name'
+        name = None
         is_private = True
     else:
         ns, _, name = ns_name.rpartition('/')
 
-    package = PHPComposerPackage(
+    package = models.PackageData(
+        datasource_id=PhpComposerJsonHandler.datasource_id,
+        type=PhpComposerJsonHandler.default_package_type,
         namespace=ns,
         name=name,
+        repository_homepage_url=get_repository_homepage_url(ns, name),
+        api_data_url=get_api_data_url(ns, name),
+        primary_language=PhpComposerJsonHandler.default_primary_language,
     )
 
     # mapping of top level composer.json items to the Package object field name
@@ -206,18 +153,96 @@ def build_package_from_json(package_data):
     ]
 
     for source, func in field_mappers:
-        logger.debug('parse: %(source)r, %(func)r' % locals())
         value = package_data.get(source)
         if value:
             if isinstance(value, str):
                 value = value.strip()
             if value:
                 func(value, package)
+
     # Parse vendor from name value
     vendor_mapper(package)
+
+    if not package.license_expression and package.declared_license:
+        package.license_expression = models.compute_normalized_license(package.declared_license)
+
     return package
 
 
+class PhpComposerLockHandler(BasePhpComposerHandler):
+    datasource_id = 'php_composer_lock'
+    path_patterns = ('*composer.lock',)
+    default_package_type = 'composer'
+    default_primary_language = 'PHP'
+    description = 'PHP composer lockfile'
+    documentation_url = 'https://getcomposer.org/doc/01-basic-usage.md#commit-your-composer-lock-file-to-version-control'
+
+    @classmethod
+    def parse(cls, location):
+        with io.open(location, encoding='utf-8') as loc:
+            package_data = json.load(loc)
+
+        packages = [
+            build_package_data(p)
+            for p in package_data.get('packages', [])
+        ]
+        packages_dev = [
+            build_package_data(p)
+            for p in package_data.get('packages-dev', [])
+        ]
+
+        required_deps = [
+            build_dep_package(p, scope='require', is_runtime=True, is_optional=False)
+            for p in packages
+        ]
+        required_dev_deps = [
+            build_dep_package(p, scope='require-dev', is_runtime=False, is_optional=True)
+            for p in packages_dev
+        ]
+
+        yield models.PackageData(
+            datasource_id=cls.datasource_id,
+            type=cls.default_package_type,
+            primary_language=cls.default_primary_language,
+            dependencies=required_deps + required_dev_deps
+        )
+
+        for package in packages + packages_dev:
+            yield package
+
+
+def compute_normalized_license(declared_license):
+    """
+    Return a normalized license expression string detected from a list of
+    declared license items or string type.
+    """
+    if not declared_license:
+        return
+
+    detected_licenses = []
+
+    if isinstance(declared_license, str):
+        if declared_license == 'proprietary':
+            return declared_license
+        if '(' in declared_license and ')' in declared_license and ' or ' in declared_license:
+            declared_license = declared_license.strip().rstrip(')').lstrip('(')
+            declared_license = declared_license.split(' or ')
+        else:
+            return models.compute_normalized_license(declared_license)
+
+    if isinstance(declared_license, list):
+        for declared in declared_license:
+            detected_license = models.compute_normalized_license(declared)
+            detected_licenses.append(detected_license)
+    else:
+        declared_license = repr(declared_license)
+        detected_license = models.compute_normalized_license(declared_license)
+
+    if detected_licenses:
+        # build a proper license expression: the defaultfor composer is OR
+        return combine_expressions(detected_licenses, 'OR')
+
+
 def licensing_mapper(licenses, package, is_private=False):
     """
     Update package licensing and return package.
@@ -314,7 +339,7 @@ def _deps_mapper(deps, package, scope, is_runtime=False, is_optional=False):
         purl = models.PackageURL(type='composer', namespace=ns, name=name).to_string()
         dep = models.DependentPackage(
             purl=purl,
-            requirement=requirement,
+            extracted_requirement=requirement,
             scope=scope,
             is_runtime=is_runtime,
             is_optional=is_optional)
@@ -371,17 +396,3 @@ def build_dep_package(package, scope, is_runtime, is_optional):
         is_optional=is_optional,
         is_resolved=True,
     )
-
-
-def build_packages_from_lock(package_data):
-    """
-    Yield composer Package objects from a package data mapping that originated
-    from a composer.lock file
-    """
-    packages = [build_package_from_json(p) for p in package_data.get('packages', [])]
-    packages_dev = [build_package_from_json(p) for p in package_data.get('packages-dev', [])]
-    required_deps = [build_dep_package(p, scope='require', is_runtime=True, is_optional=False) for p in packages]
-    required_dev_deps = [build_dep_package(p, scope='require-dev', is_runtime=False, is_optional=True) for p in packages_dev]
-    yield PHPComposerPackage(dependencies=required_deps + required_dev_deps)
-    for package in packages + packages_dev:
-        yield package
