@@ -9,17 +9,15 @@
 
 from contextlib import closing
 
-import attr
-from ftfy import fix_text
 import pefile
+from ftfy import fix_text
 
-from commoncode import filetype
 from commoncode import text
-from typecode import contenttype
 
 from packagedcode import models
 from packagedcode.models import Party
 from packagedcode.models import party_org
+from typecode import contenttype
 
 TRACE = False
 
@@ -149,11 +147,6 @@ def pe_info(location):
     if not location:
         return {}
 
-    T = contenttype.get_type(location)
-
-    if not T.is_winexe:
-        return {}
-
     result = dict([(k, None,) for k in PE_INFO_KEYS])
     extra_data = result['extra_data'] = {}
 
@@ -221,33 +214,6 @@ def pe_info(location):
     return result
 
 
-@attr.s()
-class WindowsExecutable(models.Package):
-    metafiles = ()
-    extensions = (
-        '.exe',
-        '.dll',
-        '.mui',
-        '.mun',
-        '.com',
-        '.winmd',
-        '.sys',
-        '.tlb',
-    )
-    filetypes = ('pe32', 'for ms windows',)
-    mimetypes = ('application/x-dosexec',)
-
-    default_type = 'winexe'
-
-    default_web_baseurl = None
-    default_download_baseurl = None
-    default_api_baseurl = None
-
-    @classmethod
-    def recognize(cls, location):
-        yield parse(location)
-
-
 def get_first(mapping, *keys):
     """
     Return the first value of the `keys` that is found in the `mapping`.
@@ -271,75 +237,115 @@ def concat(mapping, *keys):
     return '\n'.join(values)
 
 
-def parse(location):
-    """
-    Return a WindowsExecutable package from the file at `location` or None.
-    """
-    if not filetype.is_file(location):
-        return
-
-    T = contenttype.get_type(location)
-    if not T.is_winexe:
-        return
-
-    infos = pe_info(location)
-
-    version = get_first(
-        infos,
-        'Full Version',
-        'ProductVersion',
-        'FileVersion',
-        'Assembly Version',
+class WindowsExecutableHandler(models.NonAssemblableDatafileHandler):
+    datasource_id = 'windows_executable'
+    default_package_type = 'winexe'
+    filetypes = ('pe32', 'for ms windows',)
+    path_patterns = (
+        '*.exe',
+        '*.dll',
+        '*.mui',
+        '*.mun',
+        '*.com',
+        '*.winmd',
+        '*.sys',
+        '*.tlb',
+        '*.exe_*',
+        '*.dll_*',
+        '*.mui_*',
+        '*.mun_*',
+        '*.com_*',
+        '*.winmd_*',
+        '*.sys_*',
+        '*.tlb_*',
+        '*.ocx',
     )
-    release_date = get_first(infos, 'BuildDate')
-    if release_date:
-        if len(release_date) >= 10:
-            release_date = release_date[:10]
-        release_date = release_date.replace('/', '-')
+    description = 'Windows Portable Executable metadata'
+    documentation_url = 'https://en.wikipedia.org/wiki/Portable_Executable'
 
-    name = get_first(
-        infos,
-        'ProductName',
-        'OriginalFilename',
-        'InternalName',
-    )
-    copyr = get_first(infos, 'LegalCopyright')
+    @classmethod
+    def is_datafile(cls, location, filetypes=tuple()):
+        """
+        Return True if the file at location is highly likely to be a POM.
+        """
+        if super().is_datafile(location, filetypes=filetypes):
+            return True
 
-    LegalCopyright = copyr,
+        T = contenttype.get_type(location)
+        if T.is_winexe:
+            return True
 
-    LegalTrademarks = concat(
-        infos,
-        'LegalTrademarks',
-        'LegalTrademarks1',
-        'LegalTrademarks2',
-        'LegalTrademarks3')
+    @classmethod
+    def parse(cls, location):
+        infos = pe_info(location)
 
-    License = get_first(infos, 'License')
+        version = get_first(
+            infos,
+            'Full Version',
+            'ProductVersion',
+            'FileVersion',
+            'Assembly Version',
+        )
+        release_date = get_first(infos, 'BuildDate')
+        if release_date:
+            if len(release_date) >= 10:
+                release_date = release_date[:10]
+            release_date = release_date.replace('/', '-')
 
-    declared_license = {}
-    if LegalCopyright or LegalTrademarks or License:
-        declared_license = dict(
-            LegalCopyright=copyr,
-            LegalTrademarks=LegalTrademarks,
-            License=License
+        name = get_first(
+            infos,
+            'ProductName',
+            'OriginalFilename',
+            'InternalName',
+        )
+        copyr = get_first(infos, 'LegalCopyright')
+
+        LegalCopyright = copyr,
+
+        LegalTrademarks = concat(
+            infos,
+            'LegalTrademarks',
+            'LegalTrademarks1',
+            'LegalTrademarks2',
+            'LegalTrademarks3')
+
+        License = get_first(infos, 'License')
+
+        declared_license = {}
+        if LegalCopyright or LegalTrademarks or License:
+            declared_license = dict(
+                LegalCopyright=copyr,
+                LegalTrademarks=LegalTrademarks,
+                License=License
+            )
+
+        description = concat(infos, 'FileDescription', 'Comments')
+
+        parties = []
+        cname = get_first(infos, 'CompanyName', 'Company')
+
+        if cname:
+            parties = [Party(type=party_org, role='author', name=cname)]
+        homepage_url = get_first(infos, 'URL', 'WWW')
+
+        package_data = models.PackageData(
+            datasource_id=cls.datasource_id,
+            type=cls.default_package_type,
+            name=name,
+            version=version,
+            release_date=release_date,
+            copyright=copyr,
+            declared_license=declared_license,
+            description=description,
+            parties=parties,
+            homepage_url=homepage_url,
         )
 
-    description = concat(infos, 'FileDescription', 'Comments')
+        if not package_data.license_expression and package_data.declared_license:
+            if License:
+                lexp = models.compute_normalized_license(License)
+            else:
+                lexp = models.compute_normalized_license(package_data.declared_license)
+            package_data.license_expression = lexp
 
-    parties = []
-    cname = get_first(infos, 'CompanyName', 'Company')
-
-    if cname:
-        parties = [Party(type=party_org, role='author', name=cname)]
-    homepage_url = get_first(infos, 'URL', 'WWW')
-
-    return WindowsExecutable(
-        name=name,
-        version=version,
-        release_date=release_date,
-        copyright=copyr,
-        declared_license=declared_license,
-        description=description,
-        parties=parties,
-        homepage_url=homepage_url,
-    )
+        yield package_data
