@@ -35,43 +35,29 @@ Note: this API is unstable and still evolving.
 """
 
 
-def get_copyrights(location, deadline=sys.maxsize, **kwargs):
+def get_copyrights(
+    location,
+    deadline=sys.maxsize,
+    **kwargs,
+):
     """
     Return a mapping with a single 'copyrights' key with a value that is a list
     of mappings for copyright detected in the file at `location`.
     """
     from cluecode.copyrights import detect_copyrights
+    from cluecode.copyrights import Detection
 
-    copyrights = []
-    holders = []
-    authors = []
+    detections = detect_copyrights(
+        location,
+        include_copyrights=True,
+        include_holders=True,
+        include_authors=True,
+        include_copyright_years=True,
+        include_copyright_allrights=False,
+        deadline=deadline,
+    )
 
-    for dtype, value, start, end in detect_copyrights(location, deadline=deadline):
-
-        if dtype == 'copyrights':
-            copyrights.append(
-                dict([
-                    ('value', value),
-                    ('start_line', start),
-                    ('end_line', end)
-                ])
-            )
-        elif dtype == 'holders':
-            holders.append(
-                dict([
-                    ('value', value),
-                    ('start_line', start),
-                    ('end_line', end)
-                ])
-            )
-        elif dtype == 'authors':
-            authors.append(
-                dict([
-                    ('value', value),
-                    ('start_line', start),
-                    ('end_line', end)
-                ])
-            )
+    copyrights, holders, authors = Detection.split(detections, to_dict=True)
 
     results = dict([
         ('copyrights', copyrights),
@@ -79,10 +65,17 @@ def get_copyrights(location, deadline=sys.maxsize, **kwargs):
         ('authors', authors),
     ])
 
+    # TODO: do something if we missed the deadline
     return results
 
 
-def get_emails(location, threshold=50, test_slow_mode=False, test_error_mode=False, **kwargs):
+def get_emails(
+    location,
+    threshold=50,
+    test_slow_mode=False,
+    test_error_mode=False,
+    **kwargs,
+):
     """
     Return a mapping with a single 'emails' key with a value that is a list of
     mappings for emails detected in the file at `location`.
@@ -141,10 +134,16 @@ DEJACODE_LICENSE_URL = 'https://enterprise.dejacode.com/urn/urn:dje:license:{}'
 SCANCODE_LICENSEDB_URL = 'https://scancode-licensedb.aboutcode.org/{}'
 
 
-def get_licenses(location, min_score=0,
-                 include_text=False, license_text_diagnostics=False,
-                 license_url_template=SCANCODE_LICENSEDB_URL,
-                 deadline=sys.maxsize, **kwargs):
+def get_licenses(
+    location,
+    min_score=0,
+    include_text=False,
+    license_text_diagnostics=False,
+    license_url_template=SCANCODE_LICENSEDB_URL,
+    unknown_licenses=False,
+    deadline=sys.maxsize,
+    **kwargs,
+):
     """
     Return a mapping or detected_licenses for licenses detected in the file at
     `location`
@@ -154,15 +153,17 @@ def get_licenses(location, min_score=0,
      - 'license_expressions' with a value that is list of license expression
        strings.
 
-    `minimum_score` is a minimum score threshold from 0 to 100. The default is 0
-    means that all license matches are returned. Otherwise, matches with a score
-    below `minimum_score` are returned.
+    `min_score` is a minimum score threshold from 0 to 100. The default is 0,
+    meaning that all license matches are returned. If specified, matches with a
+    score lower than `minimum_score` are not returned.
 
     If `include_text` is True, matched text is included in the returned
     `licenses` data as well as a file-level `percentage_of_license_text` percentage to
     indicate the overall proportion of detected license text and license notice
     words in the file. This is used to determine if a file contains mostly
     licensing information.
+
+    If ``unknown_licenses`` is True, also detect unknown licenses.
     """
     from licensedcode import cache
     from licensedcode.spans import Span
@@ -173,7 +174,11 @@ def get_licenses(location, min_score=0,
     detected_expressions = []
 
     matches = idx.match(
-        location=location, min_score=min_score, deadline=deadline, **kwargs
+        location=location,
+        min_score=min_score,
+        deadline=deadline,
+        unknown_licenses=unknown_licenses,
+        **kwargs,
     )
 
     qspans = []
@@ -208,8 +213,11 @@ def get_licenses(location, min_score=0,
 
 
 def _licenses_data_from_match(
-        match, include_text=False, license_text_diagnostics=False,
-        license_url_template=SCANCODE_LICENSEDB_URL):
+    match,
+    include_text=False,
+    license_text_diagnostics=False,
+    license_url_template=SCANCODE_LICENSEDB_URL,
+):
     """
     Return a list of "licenses" scan data built from a license match.
     Used directly only internally for testing.
@@ -287,22 +295,25 @@ def _licenses_data_from_match(
 SCANCODE_DEBUG_PACKAGE_API = os.environ.get('SCANCODE_DEBUG_PACKAGE_API', False)
 
 
-def get_package_info(location, **kwargs):
+def _get_package_data(location, application=True, system=False, **kwargs):
     """
-    Return a mapping of package manifest information detected in the
-    file at `location`.
-
+    Return a mapping of package manifest information detected in the file at ``location``.
+    Include ``application`` packages (such as pypi) and/or ``system`` packages.
     Note that all exceptions are caught if there are any errors while parsing a
     package manifest.
     """
-    from packagedcode.recognize import recognize_packages
+    assert application or system
+    from packagedcode.recognize import recognize_package_data
     try:
-        recognized_packages = recognize_packages(location)
-        if recognized_packages:
-            return dict(packages=[package.to_dict() for package in recognized_packages])
+        return recognize_package_data(
+            location=location,
+            application=application,
+            system=system
+        ) or []
+
     except Exception as e:
         if TRACE:
-            logger.error('get_package_info: {}: Exception: {}'.format(location, e))
+            logger.error(f'_get_package_data: location: {location!r}: Exception: {e}')
 
         if SCANCODE_DEBUG_PACKAGE_API:
             raise
@@ -310,7 +321,40 @@ def get_package_info(location, **kwargs):
             # attention: we are swallowing ALL exceptions here!
             pass
 
-    return dict(packages=[])
+
+def get_package_info(location, **kwargs):
+    """
+    Return a mapping of package information detected in the file at `location`.
+    This API function is DEPRECATED, use `get_package_data` instead.
+    """
+    import warnings
+    warnings.warn(
+        "`get_package_info` is deprecated. Use `get_package_data` instead.",
+        DeprecationWarning,
+        stacklevel=1
+    )
+
+    packages = _get_package_data(location, **kwargs) or []
+    return dict(packages=[p.to_dict() for p in packages])
+
+
+def get_package_data(location, application=True, system=False, **kwargs):
+    """
+    Return a mapping of package manifest information detected in the file at
+    `location`.
+    Include ``application`` packages (such as pypi) and/or ``system`` packages.
+    """
+    if TRACE:
+        print('  scancode.api.get_package_data: kwargs', kwargs)
+
+    package_datas = _get_package_data(
+        location=location,
+        application=application,
+        system=system,
+        **kwargs,
+    ) or []
+
+    return dict(package_data=[pd.to_dict() for pd in package_datas])
 
 
 def get_file_info(location, **kwargs):
